rai\_toolbox.optim.ParamTransformingOptimizer
=============================================

.. currentmodule:: rai_toolbox.optim

.. autoclass:: ParamTransformingOptimizer

   
   .. automethod:: __init__
   .. automethod:: _pre_step_transform_
   .. automethod:: _post_step_transform_
   .. automethod:: _apply_pre_step_transform_
   .. automethod:: _apply_post_step_transform_
   
   .. rubric:: Methods

   .. autosummary::
   
      ~ParamTransformingOptimizer.__init__
      ~ParamTransformingOptimizer._pre_step_transform_
      ~ParamTransformingOptimizer._post_step_transform_
      ~ParamTransformingOptimizer._apply_pre_step_transform_
      ~ParamTransformingOptimizer._apply_post_step_transform_
